@@ -36,19 +36,20 @@ public final class WorkerPool<T>
 
     /**
      * Create a worker pool to enable an array of {@link WorkHandler}s to consume published sequences.
-     *
+     * <p>
      * This option requires a pre-configured {@link RingBuffer} which must have {@link RingBuffer#addGatingSequences(Sequence...)}
      * called before the work pool is started.
      *
-     * @param ringBuffer of events to be consumed.
-     * @param sequenceBarrier on which the workers will depend.
+     * @param ringBuffer       of events to be consumed.
+     * @param sequenceBarrier  on which the workers will depend.
      * @param exceptionHandler to callback when an error occurs which is not handled by the {@link WorkHandler}s.
-     * @param workHandlers to distribute the work load across.
+     * @param workHandlers     to distribute the work load across.
      */
-    public WorkerPool(final RingBuffer<T> ringBuffer,
-                      final SequenceBarrier sequenceBarrier,
-                      final ExceptionHandler<? super T> exceptionHandler,
-                      final WorkHandler<? super T>... workHandlers)
+    public WorkerPool(
+        final RingBuffer<T> ringBuffer,
+        final SequenceBarrier sequenceBarrier,
+        final ExceptionHandler<? super T> exceptionHandler,
+        final WorkHandler<? super T>... workHandlers)
     {
         this.ringBuffer = ringBuffer;
         final int numWorkers = workHandlers.length;
@@ -56,26 +57,28 @@ public final class WorkerPool<T>
 
         for (int i = 0; i < numWorkers; i++)
         {
-            workProcessors[i] = new WorkProcessor<T>(ringBuffer,
-                                                     sequenceBarrier,
-                                                     workHandlers[i],
-                                                     exceptionHandler,
-                                                     workSequence);
+            workProcessors[i] = new WorkProcessor<T>(
+                ringBuffer,
+                sequenceBarrier,
+                workHandlers[i],
+                exceptionHandler,
+                workSequence);
         }
     }
 
     /**
      * Construct a work pool with an internal {@link RingBuffer} for convenience.
-     *
+     * <p>
      * This option does not require {@link RingBuffer#addGatingSequences(Sequence...)} to be called before the work pool is started.
      *
-     * @param eventFactory for filling the {@link RingBuffer}
+     * @param eventFactory     for filling the {@link RingBuffer}
      * @param exceptionHandler to callback when an error occurs which is not handled by the {@link WorkHandler}s.
-     * @param workHandlers to distribute the work load across.
+     * @param workHandlers     to distribute the work load across.
      */
-    public WorkerPool(final EventFactory<T> eventFactory,
-                      final ExceptionHandler<? super T> exceptionHandler,
-                      final WorkHandler<? super T>... workHandlers)
+    public WorkerPool(
+        final EventFactory<T> eventFactory,
+        final ExceptionHandler<? super T> exceptionHandler,
+        final WorkHandler<? super T>... workHandlers)
     {
         ringBuffer = RingBuffer.createMultiProducer(eventFactory, 1024, new BlockingWaitStrategy());
         final SequenceBarrier barrier = ringBuffer.newBarrier();
@@ -84,11 +87,12 @@ public final class WorkerPool<T>
 
         for (int i = 0; i < numWorkers; i++)
         {
-            workProcessors[i] = new WorkProcessor<T>(ringBuffer,
-                                                     barrier,
-                                                     workHandlers[i],
-                                                     exceptionHandler,
-                                                     workSequence);
+            workProcessors[i] = new WorkProcessor<T>(
+                ringBuffer,
+                barrier,
+                workHandlers[i],
+                exceptionHandler,
+                workSequence);
         }
 
         ringBuffer.addGatingSequences(getWorkerSequences());
