@@ -32,21 +32,28 @@ import com.lmax.disruptor.WorkerPool;
 import com.lmax.disruptor.util.Util;
 
 import java.util.concurrent.Executor;
+import java.util.concurrent.ThreadFactory;
 import java.util.concurrent.TimeUnit;
 import java.util.concurrent.atomic.AtomicBoolean;
 
 /**
- * A DSL-style API for setting up the disruptor pattern around a ring buffer (aka the Builder pattern).
- *
- * <p>A simple example of setting up the disruptor with two event handlers that must process events in order:</p>
- *
- * <pre><code> Disruptor&lt;MyEvent&gt; disruptor = new Disruptor&lt;MyEvent&gt;(MyEvent.FACTORY, 32, Executors.newCachedThreadPool());
+ * A DSL-style API for setting up the disruptor pattern around a ring buffer
+ * (aka the Builder pattern).
+ * <p>
+ * <p>
+ * A simple example of setting up the disruptor with two event handlers that
+ * must process events in order:
+ * </p>
+ * <p>
+ * <pre>
+ * <code>Disruptor&lt;MyEvent&gt; disruptor = new Disruptor&lt;MyEvent&gt;(MyEvent.FACTORY, 32, Executors.newCachedThreadPool());
  * EventHandler&lt;MyEvent&gt; handler1 = new EventHandler&lt;MyEvent&gt;() { ... };
  * EventHandler&lt;MyEvent&gt; handler2 = new EventHandler&lt;MyEvent&gt;() { ... };
  * disruptor.handleEventsWith(handler1);
  * disruptor.after(handler1).handleEventsWith(handler2);
  *
- * RingBuffer ringBuffer = disruptor.start();</code></pre>
+ * RingBuffer ringBuffer = disruptor.start();</code>
+ * </pre>
  *
  * @param <T> the type of event used.
  */
@@ -56,15 +63,20 @@ public class Disruptor<T>
     private final Executor executor;
     private final ConsumerRepository<T> consumerRepository = new ConsumerRepository<T>();
     private final AtomicBoolean started = new AtomicBoolean(false);
-    private ExceptionHandler exceptionHandler;
+    private ExceptionHandler<? super T> exceptionHandler = new ExceptionHandlerWrapper<T>();
 
     /**
-     * Create a new Disruptor.
+     * Create a new Disruptor. Will default to {@link com.lmax.disruptor.BlockingWaitStrategy} and
+     * {@link ProducerType}.MULTI
+     *
+     * @deprecated Use a {@link ThreadFactory} instead of an {@link Executor} as a the ThreadFactory
+     * is able to report errors then it is unable to construct a thread to run a producer.
      *
      * @param eventFactory   the factory to create events in the ring buffer.
      * @param ringBufferSize the size of the ring buffer.
      * @param executor       an {@link Executor} to execute event processors.
      */
+    @Deprecated
     public Disruptor(final EventFactory<T> eventFactory, final int ringBufferSize, final Executor executor)
     {
         this(RingBuffer.createMultiProducer(eventFactory, ringBufferSize), executor);
@@ -73,19 +85,58 @@ public class Disruptor<T>
     /**
      * Create a new Disruptor.
      *
+     * @deprecated Use a {@link ThreadFactory} instead of an {@link Executor} as a the ThreadFactory
+     * is able to report errors then it is unable to construct a thread to run a producer.
+     *
      * @param eventFactory   the factory to create events in the ring buffer.
+     * @param ringBufferSize the size of the ring buffer, must be power of 2.
      * @param executor       an {@link Executor} to execute event processors.
      * @param producerType   the claim strategy to use for the ring buffer.
      * @param waitStrategy   the wait strategy to use for the ring buffer.
      */
-    public Disruptor(final EventFactory<T> eventFactory,
-                     final int ringBufferSize,
-                     final Executor executor,
-                     final ProducerType producerType,
-                     final WaitStrategy waitStrategy)
+    @Deprecated
+    public Disruptor(
+        final EventFactory<T> eventFactory,
+        final int ringBufferSize,
+        final Executor executor,
+        final ProducerType producerType,
+        final WaitStrategy waitStrategy)
     {
-        this(RingBuffer.create(producerType, eventFactory, ringBufferSize, waitStrategy),
-             executor);
+        this(RingBuffer.create(producerType, eventFactory, ringBufferSize, waitStrategy), executor);
+    }
+
+    /**
+     * Create a new Disruptor. Will default to {@link com.lmax.disruptor.BlockingWaitStrategy} and
+     * {@link ProducerType}.MULTI
+     *
+     * @param eventFactory   the factory to create events in the ring buffer.
+     * @param ringBufferSize the size of the ring buffer.
+     * @param threadFactory  a {@link ThreadFactory} to create threads to for processors.
+     */
+    public Disruptor(final EventFactory<T> eventFactory, final int ringBufferSize, final ThreadFactory threadFactory)
+    {
+        this(RingBuffer.createMultiProducer(eventFactory, ringBufferSize), new BasicExecutor(threadFactory));
+    }
+
+    /**
+     * Create a new Disruptor.
+     *
+     * @param eventFactory   the factory to create events in the ring buffer.
+     * @param ringBufferSize the size of the ring buffer, must be power of 2.
+     * @param threadFactory  a {@link ThreadFactory} to create threads for processors.
+     * @param producerType   the claim strategy to use for the ring buffer.
+     * @param waitStrategy   the wait strategy to use for the ring buffer.
+     */
+    public Disruptor(
+            final EventFactory<T> eventFactory,
+            final int ringBufferSize,
+            final ThreadFactory threadFactory,
+            final ProducerType producerType,
+            final WaitStrategy waitStrategy)
+    {
+        this(RingBuffer.create(
+                               producerType, eventFactory, ringBufferSize, waitStrategy),
+                new BasicExecutor(threadFactory));
     }
 
     /**
@@ -100,7 +151,7 @@ public class Disruptor<T>
     /**
      * <p>Set up event handlers to handle events from the ring buffer. These handlers will process events
      * as soon as they become available, in parallel.</p>
-     *
+     * <p>
      * <p>This method can be used as the start of a chain. For example if the handler <code>A</code> must
      * process events before handler <code>B</code>:</p>
      * <pre><code>dw.handleEventsWith(A).then(B);</code></pre>
@@ -117,11 +168,11 @@ public class Disruptor<T>
     /**
      * <p>Set up custom event processors to handle events from the ring buffer. The Disruptor will
      * automatically start these processors when {@link #start()} is called.</p>
-     *
+     * <p>
      * <p>This method can be used as the start of a chain. For example if the handler <code>A</code> must
      * process events before handler <code>B</code>:</p>
      * <pre><code>dw.handleEventsWith(A).then(B);</code></pre>
-     *
+     * <p>
      * <p>Since this is the start of the chain, the processor factories will always be passed an empty <code>Sequence</code>
      * array, so the factory isn't necessary in this case. This method is provided for consistency with
      * {@link EventHandlerGroup#handleEventsWith(EventProcessorFactory...)} and {@link EventHandlerGroup#then(EventProcessorFactory...)}
@@ -139,7 +190,7 @@ public class Disruptor<T>
     /**
      * <p>Set up custom event processors to handle events from the ring buffer. The Disruptor will
      * automatically start this processors when {@link #start()} is called.</p>
-     *
+     * <p>
      * <p>This method can be used as the start of a chain. For example if the processor <code>A</code> must
      * process events before handler <code>B</code>:</p>
      * <pre><code>dw.handleEventsWith(A).then(B);</code></pre>
@@ -149,7 +200,7 @@ public class Disruptor<T>
      */
     public EventHandlerGroup<T> handleEventsWith(final EventProcessor... processors)
     {
-        for (EventProcessor processor : processors)
+        for (final EventProcessor processor : processors)
         {
             consumerRepository.add(processor);
         }
@@ -173,16 +224,35 @@ public class Disruptor<T>
 
     /**
      * <p>Specify an exception handler to be used for any future event handlers.</p>
-     *
+     * <p>
      * <p>Note that only event handlers set up after calling this method will use the exception handler.</p>
      *
      * @param exceptionHandler the exception handler to use for any future {@link EventProcessor}.
+     * @deprecated This method only applies to future event handlers. Use setDefaultExceptionHandler instead which applies to existing and new event handlers.
      */
-    public void handleExceptionsWith(final ExceptionHandler exceptionHandler)
+    public void handleExceptionsWith(final ExceptionHandler<? super T> exceptionHandler)
     {
         this.exceptionHandler = exceptionHandler;
     }
 
+    /**
+     * <p>Specify an exception handler to be used for event handlers and worker pools created by this Disruptor.</p>
+     * <p>
+     * <p>The exception handler will be used by existing and future event handlers and worker pools created by this Disruptor instance.</p>
+     *
+     * @param exceptionHandler the exception handler to use.
+     */
+    @SuppressWarnings("unchecked")
+    public void setDefaultExceptionHandler(final ExceptionHandler<? super T> exceptionHandler)
+    {
+        checkNotStarted();
+        if (!(this.exceptionHandler instanceof ExceptionHandlerWrapper))
+        {
+            throw new IllegalStateException("setDefaultExceptionHandler can not be used after handleExceptionsWith");
+        }
+        ((ExceptionHandlerWrapper<T>)this.exceptionHandler).switchTo(exceptionHandler);
+    }
+
     /**
      * Override the default exception handler for a specific handler.
      * <pre>disruptorWizard.handleExceptionsIn(eventHandler).with(exceptionHandler);</pre>
@@ -190,7 +260,7 @@ public class Disruptor<T>
      * @param eventHandler the event handler to set a different exception handler for.
      * @return an ExceptionHandlerSetting dsl object - intended to be used by chaining the with method call.
      */
-    public ExceptionHandlerSetting<?> handleExceptionsFor(final EventHandler<T> eventHandler)
+    public ExceptionHandlerSetting<T> handleExceptionsFor(final EventHandler<T> eventHandler)
     {
         return new ExceptionHandlerSetting<T>(eventHandler, consumerRepository);
     }
@@ -198,7 +268,7 @@ public class Disruptor<T>
     /**
      * <p>Create a group of event handlers to be used as a dependency.
      * For example if the handler <code>A</code> must process events before handler <code>B</code>:</p>
-     *
+     * <p>
      * <pre><code>dw.after(A).handleEventsWith(B);</code></pre>
      *
      * @param handlers the event handlers, previously set up with {@link #handleEventsWith(com.lmax.disruptor.EventHandler[])},
@@ -208,7 +278,7 @@ public class Disruptor<T>
     @SuppressWarnings("varargs")
     public EventHandlerGroup<T> after(final EventHandler<T>... handlers)
     {
-        Sequence[] sequences = new Sequence[handlers.length];
+        final Sequence[] sequences = new Sequence[handlers.length];
         for (int i = 0, handlersLength = handlers.length; i < handlersLength; i++)
         {
             sequences[i] = consumerRepository.getSequenceFor(handlers[i]);
@@ -227,7 +297,7 @@ public class Disruptor<T>
      */
     public EventHandlerGroup<T> after(final EventProcessor... processors)
     {
-        for (EventProcessor processor : processors)
+        for (final EventProcessor processor : processors)
         {
             consumerRepository.add(processor);
         }
@@ -249,9 +319,9 @@ public class Disruptor<T>
      * Publish an event to the ring buffer.
      *
      * @param eventTranslator the translator that will load data into the event.
-     * @param arg A single argument to load into the event
+     * @param arg             A single argument to load into the event
      */
-    public <A> void publishEvent(final EventTranslatorOneArg<T, A> eventTranslator, A arg)
+    public <A> void publishEvent(final EventTranslatorOneArg<T, A> eventTranslator, final A arg)
     {
         ringBuffer.publishEvent(eventTranslator, arg);
     }
@@ -260,30 +330,30 @@ public class Disruptor<T>
      * Publish a batch of events to the ring buffer.
      *
      * @param eventTranslator the translator that will load data into the event.
-     * @param arg An array single arguments to load into the events. One Per event.
+     * @param arg             An array single arguments to load into the events. One Per event.
      */
-    public <A> void publishEvents(final EventTranslatorOneArg<T, A> eventTranslator, A[] arg)
+    public <A> void publishEvents(final EventTranslatorOneArg<T, A> eventTranslator, final A[] arg)
     {
         ringBuffer.publishEvents(eventTranslator, arg);
     }
 
     /**
      * <p>Starts the event processors and returns the fully configured ring buffer.</p>
-     *
+     * <p>
      * <p>The ring buffer is set up to prevent overwriting any entry that is yet to
      * be processed by the slowest event processor.</p>
-     *
+     * <p>
      * <p>This method must only be called once after all event processors have been added.</p>
      *
      * @return the configured ring buffer.
      */
     public RingBuffer<T> start()
     {
-        Sequence[] gatingSequences = consumerRepository.getLastSequenceInChain(true);
+        final Sequence[] gatingSequences = consumerRepository.getLastSequenceInChain(true);
         ringBuffer.addGatingSequences(gatingSequences);
 
         checkOnlyStartedOnce();
-        for (ConsumerInfo consumerInfo : consumerRepository)
+        for (final ConsumerInfo consumerInfo : consumerRepository)
         {
             consumerInfo.start(executor);
         }
@@ -296,7 +366,7 @@ public class Disruptor<T>
      */
     public void halt()
     {
-        for (ConsumerInfo consumerInfo : consumerRepository)
+        for (final ConsumerInfo consumerInfo : consumerRepository)
         {
             consumerInfo.halt();
         }
@@ -306,7 +376,7 @@ public class Disruptor<T>
      * Waits until all events currently in the disruptor have been processed by all event processors
      * and then halts the processors.  It is critical that publishing to the ring buffer has stopped
      * before calling this method, otherwise it may never return.
-     *
+     * <p>
      * <p>This method will not shutdown the executor, nor will it await the final termination of the
      * processor threads.</p>
      */
@@ -316,7 +386,7 @@ public class Disruptor<T>
         {
             shutdown(-1, TimeUnit.MILLISECONDS);
         }
-        catch (TimeoutException e)
+        catch (final TimeoutException e)
         {
             exceptionHandler.handleOnShutdownException(e);
         }
@@ -325,7 +395,7 @@ public class Disruptor<T>
     /**
      * <p>Waits until all events currently in the disruptor have been processed by all event processors
      * and then halts the processors.</p>
-     *
+     * <p>
      * <p>This method will not shutdown the executor, nor will it await the final termination of the
      * processor threads.</p>
      *
@@ -334,7 +404,7 @@ public class Disruptor<T>
      */
     public void shutdown(final long timeout, final TimeUnit timeUnit) throws TimeoutException
     {
-        long timeOutAt = System.currentTimeMillis() + timeUnit.toMillis(timeout);
+        final long timeOutAt = System.currentTimeMillis() + timeUnit.toMillis(timeout);
         while (hasBacklog())
         {
             if (timeout >= 0 && System.currentTimeMillis() > timeOutAt)
@@ -408,7 +478,7 @@ public class Disruptor<T>
     private boolean hasBacklog()
     {
         final long cursor = ringBuffer.getCursor();
-        for (Sequence consumer : consumerRepository.getLastSequenceInChain(false))
+        for (final Sequence consumer : consumerRepository.getLastSequenceInChain(false))
         {
             if (cursor > consumer.get())
             {
@@ -418,8 +488,9 @@ public class Disruptor<T>
         return false;
     }
 
-    EventHandlerGroup<T> createEventProcessors(final Sequence[] barrierSequences,
-                                               final EventHandler<? super T>[] eventHandlers)
+    EventHandlerGroup<T> createEventProcessors(
+        final Sequence[] barrierSequences,
+        final EventHandler<? super T>[] eventHandlers)
     {
         checkNotStarted();
 
@@ -430,7 +501,8 @@ public class Disruptor<T>
         {
             final EventHandler<? super T> eventHandler = eventHandlers[i];
 
-            final BatchEventProcessor<T> batchEventProcessor = new BatchEventProcessor<T>(ringBuffer, barrier, eventHandler);
+            final BatchEventProcessor<T> batchEventProcessor =
+                new BatchEventProcessor<T>(ringBuffer, barrier, eventHandler);
 
             if (exceptionHandler != null)
             {
@@ -449,7 +521,8 @@ public class Disruptor<T>
         return new EventHandlerGroup<T>(this, consumerRepository, processorSequences);
     }
 
-    EventHandlerGroup<T> createEventProcessors(final Sequence[] barrierSequences, final EventProcessorFactory<T>[] processorFactories)
+    EventHandlerGroup<T> createEventProcessors(
+        final Sequence[] barrierSequences, final EventProcessorFactory<T>[] processorFactories)
     {
         final EventProcessor[] eventProcessors = new EventProcessor[processorFactories.length];
         for (int i = 0; i < processorFactories.length; i++)
@@ -459,7 +532,8 @@ public class Disruptor<T>
         return handleEventsWith(eventProcessors);
     }
 
-    EventHandlerGroup<T> createWorkerPool(final Sequence[] barrierSequences, final WorkHandler<? super T>[] workHandlers)
+    EventHandlerGroup<T> createWorkerPool(
+        final Sequence[] barrierSequences, final WorkHandler<? super T>[] workHandlers)
     {
         final SequenceBarrier sequenceBarrier = ringBuffer.newBarrier(barrierSequences);
         final WorkerPool<T> workerPool = new WorkerPool<T>(ringBuffer, sequenceBarrier, exceptionHandler, workHandlers);
