@@ -34,9 +34,10 @@ public class EventHandlerGroup<T>
     private final ConsumerRepository<T> consumerRepository;
     private final Sequence[] sequences;
 
-    EventHandlerGroup(final Disruptor<T> disruptor,
-                      final ConsumerRepository<T> consumerRepository,
-                      final Sequence[] sequences)
+    EventHandlerGroup(
+        final Disruptor<T> disruptor,
+        final ConsumerRepository<T> consumerRepository,
+        final Sequence[] sequences)
     {
         this.disruptor = disruptor;
         this.consumerRepository = consumerRepository;
@@ -53,7 +54,8 @@ public class EventHandlerGroup<T>
     {
         final Sequence[] combinedSequences = new Sequence[this.sequences.length + otherHandlerGroup.sequences.length];
         System.arraycopy(this.sequences, 0, combinedSequences, 0, this.sequences.length);
-        System.arraycopy(otherHandlerGroup.sequences, 0, combinedSequences, this.sequences.length, otherHandlerGroup.sequences.length);
+        System
+            .arraycopy(otherHandlerGroup.sequences, 0, combinedSequences, this.sequences.length, otherHandlerGroup.sequences.length);
         return new EventHandlerGroup<T>(disruptor, consumerRepository, combinedSequences);
     }
 
@@ -80,10 +82,10 @@ public class EventHandlerGroup<T>
     /**
      * Set up batch handlers to consume events from the ring buffer. These handlers will only process events
      * after every {@link EventProcessor} in this group has processed the event.
-     *
+     * <p>
      * <p>This method is generally used as part of a chain. For example if the handler <code>A</code> must
      * process events before handler <code>B</code>:</p>
-     *
+     * <p>
      * <pre><code>dw.handleEventsWith(A).then(B);</code></pre>
      *
      * @param handlers the batch handlers that will process events.
@@ -97,7 +99,7 @@ public class EventHandlerGroup<T>
     /**
      * <p>Set up custom event processors to handle events from the ring buffer. The Disruptor will
      * automatically start these processors when {@link Disruptor#start()} is called.</p>
-     *
+     * <p>
      * <p>This method is generally used as part of a chain. For example if the handler <code>A</code> must
      * process events before handler <code>B</code>:</p>
      *
@@ -113,10 +115,10 @@ public class EventHandlerGroup<T>
      * Set up a worker pool to handle events from the ring buffer. The worker pool will only process events
      * after every {@link EventProcessor} in this group has processed the event. Each event will be processed
      * by one of the work handler instances.
-     *
+     * <p>
      * <p>This method is generally used as part of a chain. For example if the handler <code>A</code> must
      * process events before the worker pool with handlers <code>B, C</code>:</p>
-     *
+     * <p>
      * <pre><code>dw.handleEventsWith(A).thenHandleEventsWithWorkerPool(B, C);</code></pre>
      *
      * @param handlers the work handlers that will process events. Each work handler instance will provide an extra thread in the worker pool.
@@ -130,10 +132,10 @@ public class EventHandlerGroup<T>
     /**
      * Set up batch handlers to handle events from the ring buffer. These handlers will only process events
      * after every {@link EventProcessor} in this group has processed the event.
-     *
+     * <p>
      * <p>This method is generally used as part of a chain. For example if <code>A</code> must
      * process events before <code>B</code>:</p>
-     *
+     * <p>
      * <pre><code>dw.after(A).handleEventsWith(B);</code></pre>
      *
      * @param handlers the batch handlers that will process events.
@@ -147,10 +149,10 @@ public class EventHandlerGroup<T>
     /**
      * <p>Set up custom event processors to handle events from the ring buffer. The Disruptor will
      * automatically start these processors when {@link Disruptor#start()} is called.</p>
-     *
+     * <p>
      * <p>This method is generally used as part of a chain. For example if <code>A</code> must
      * process events before <code>B</code>:</p>
-     *
+     * <p>
      * <pre><code>dw.after(A).handleEventsWith(B);</code></pre>
      *
      * @param eventProcessorFactories the event processor factories to use to create the event processors that will process events.
@@ -165,10 +167,10 @@ public class EventHandlerGroup<T>
      * Set up a worker pool to handle events from the ring buffer. The worker pool will only process events
      * after every {@link EventProcessor} in this group has processed the event. Each event will be processed
      * by one of the work handler instances.
-     *
+     * <p>
      * <p>This method is generally used as part of a chain. For example if the handler <code>A</code> must
      * process events before the worker pool with handlers <code>B, C</code>:</p>
-     *
+     * <p>
      * <pre><code>dw.after(A).handleEventsWithWorkerPool(B, C);</code></pre>
      *
      * @param handlers the work handlers that will process events. Each work handler instance will provide an extra thread in the worker pool.
