@@ -45,12 +45,13 @@ public final class FatalExceptionHandlerTest
 
         final Logger logger = context.mock(Logger.class);
 
-        context.checking(new Expectations()
-        {
+        context.checking(
+            new Expectations()
             {
-                oneOf(logger).log(Level.SEVERE, "Exception processing: 0 " + event, causeException);
-            }
-        });
+                {
+                    oneOf(logger).log(Level.SEVERE, "Exception processing: 0 " + event, causeException);
+                }
+            });
 
         ExceptionHandler<Object> exceptionHandler = new FatalExceptionHandler(logger);
 
