@@ -49,22 +49,23 @@ public class ConsumerRepositoryTest
 
         final Sequence sequence1 = new Sequence();
         final Sequence sequence2 = new Sequence();
-        mockery.checking(new Expectations()
-        {
+        mockery.checking(
+            new Expectations()
             {
-                allowing(eventProcessor1).getSequence();
-                will(returnValue(sequence1));
+                {
+                    allowing(eventProcessor1).getSequence();
+                    will(returnValue(sequence1));
 
-                allowing(eventProcessor1).isRunning();
-                will(returnValue(true));
+                    allowing(eventProcessor1).isRunning();
+                    will(returnValue(true));
 
-                allowing(eventProcessor2).getSequence();
-                will(returnValue(sequence2));
+                    allowing(eventProcessor2).getSequence();
+                    will(returnValue(sequence2));
 
-                allowing(eventProcessor2).isRunning();
-                will(returnValue(true));
-            }
-        });
+                    allowing(eventProcessor2).isRunning();
+                    will(returnValue(true));
+                }
+            });
         handler1 = new SleepingEventHandler();
         handler2 = new SleepingEventHandler();
 
@@ -131,7 +132,7 @@ public class ConsumerRepositoryTest
                 seen1 = true;
             }
             else if (!seen2 && eventProcessorInfo.getEventProcessor() == eventProcessor2 &&
-                     eventProcessorInfo.getHandler() == handler2)
+                eventProcessorInfo.getHandler() == handler2)
             {
                 seen2 = true;
             }
